==> cerebrium-1.41.10-py3-none-any.whl: cerebrium/commands/init.py <==
import cProfile
import os
import sys
from pstats import Stats
from typing import Annotated, Optional

import bugsnag
import toml
import typer
from rich.console import Group
from rich.panel import Panel
from rich.text import Text

from cerebrium import api, __version__
from cerebrium.api import cerebrium_request
from cerebrium.config import (
    CerebriumConfig,
    ScalingConfig,
    HardwareConfig,
    DeploymentConfig,
    DependencyConfig,
    CustomRuntimeConfig,
    PartnerConfig,
)
from cerebrium.utils.check_cli_version import print_update_cli_message
from cerebrium.utils.deploy import package_app, get_function_names
from cerebrium.utils.display import confirm_partner_service_deployment
from cerebrium.utils.logging import cerebrium_log, console
from cerebrium.utils.project import get_current_project_context

_EXAMPLE_MAIN = """
def run(param_1: str, param_2: str, run_id):  # run_id is optional, injected by Cerebrium at runtime
    my_results = {"1": param_1, "2": param_2}
    my_status_code = 200 # if you want to return a specific status code

    return {"my_result": my_results, "status_code": my_status_code} # return your results

# To deploy your app, run:
# cerebrium deploy
"""

cortex_cli = typer.Typer(no_args_is_help=True)


@cortex_cli.command("init")
def init(
    name: Annotated[str, typer.Argument(help="Name of the Cortex deployment.")],
    dir: Annotated[str, typer.Option(help="Directory to create the Cortex deployment.")] = "./",
):
    """
    Initialize an empty Cerebrium Cortex project.
    """
    path = os.path.join(dir, name)
    toml_path = os.path.join(path, "cerebrium.toml")
    main_path = os.path.join(path, "main.py")
    if dir != "./":
        console.print(f"Initializing Cerebrium Cortex project in new directory {name}")
    else:
        console.print(f"Initializing Cerebrium Cortex project in directory {path}")

    print_update_cli_message()

    if not os.path.exists(path):
        os.makedirs(path)
    else:
        cerebrium_log(
            level="WARNING",
            message="Directory already exists. Please choose a different name.",
            prefix_separator="\t",
        )
        bugsnag.notify(Exception("Directory already exists error."))
        raise typer.Exit(1)

    if not os.path.exists(main_path):
        with open(main_path, "w", newline="\n") as f:
            f.write(_EXAMPLE_MAIN)

    scaling_config = ScalingConfig()
    hardware_config = HardwareConfig()
    dependency_config = DependencyConfig()
    deployment_config = DeploymentConfig(name=name)
    config = CerebriumConfig(
        scaling=scaling_config,
        hardware=hardware_config,
        deployment=deployment_config,
        dependencies=dependency_config,
        custom_runtime=None,
    )
    config.to_toml(toml_path)
    console.print("Cerebrium Cortex project initialized successfully!")
    console.print(f"cd {path} && cerebrium deploy to get started")

==> cerebrium-1.42.0-py3-none-any.whl: cerebrium/commands/init.py <==
import cProfile
import os
import sys
from pstats import Stats
from typing import Annotated, Optional

import bugsnag
import toml
import typer
from rich.console import Group
from rich.panel import Panel
from rich.text import Text

from cerebrium import api, __version__
from cerebrium.api import cerebrium_request
from cerebrium.config import (
    CerebriumConfig,
    ScalingConfig,
    HardwareConfig,
    DeploymentConfig,
    DependencyConfig,
    CustomRuntimeConfig,
    PartnerConfig,
)
from cerebrium.utils.check_cli_version import print_update_cli_message
from cerebrium.utils.deploy import package_app, get_function_names
from cerebrium.utils.display import confirm_partner_service_deployment
from cerebrium.utils.logging import cerebrium_log, console
from cerebrium.context import get_current_project

_EXAMPLE_MAIN = """
def run(param_1: str, param_2: str, run_id):  # run_id is optional, injected by Cerebrium at runtime
    my_results = {"1": param_1, "2": param_2}
    my_status_code = 200 # if you want to return a specific status code

    return {"my_result": my_results, "status_code": my_status_code} # return your results

# To deploy your app, run:
# cerebrium deploy
"""

cortex_cli = typer.Typer(no_args_is_help=True)


@cortex_cli.command("init")
def init(
    name: Annotated[str, typer.Argument(help="Name of the Cortex deployment.")],
    dir: Annotated[str, typer.Option(help="Directory to create the Cortex deployment.")] = "./",
):
    """
    Initialize an empty Cerebrium Cortex project.
    """
    path = os.path.join(dir, name)
    toml_path = os.path.join(path, "cerebrium.toml")
    main_path = os.path.join(path, "main.py")
    if dir != "./":
        console.print(f"Initializing Cerebrium Cortex project in new directory {name}")
    else:
        console.print(f"Initializing Cerebrium Cortex project in directory {path}")

    print_update_cli_message()

    if not os.path.exists(path):
        os.makedirs(path)
    else:
        cerebrium_log(
            level="WARNING",
            message="Directory already exists. Please choose a different name.",
            prefix_separator="\t",
        )
        bugsnag.notify(Exception("Directory already exists error."))
        raise typer.Exit(1)

    if not os.path.exists(main_path):
        with open(main_path, "w", newline="\n") as f:
            f.write(_EXAMPLE_MAIN)

    scaling_config = ScalingConfig()
    hardware_config = HardwareConfig()
    dependency_config = DependencyConfig()
    deployment_config = DeploymentConfig(name=name)
    config = CerebriumConfig(
        scaling=scaling_config,
        hardware=hardware_config,
        deployment=deployment_config,
        dependencies=dependency_config,
        custom_runtime=None,
    )
    config.to_toml(toml_path)
    console.print("Cerebrium Cortex project initialized successfully!")
    console.print(f"cd {path} && cerebrium deploy to get started")
